# coding: utf-8

from django.contrib import admin
from django.utils.translation import ugettext as _
from modeltranslation.admin import TranslationAdmin

from jmb.jadmin import JumboModelAdmin
from .models import Faq, Topic, Area
from .forms import FaqForm

log_fieldset = (
    _('logs admin'), {
        'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify'),
        'classes': ('collapse',)
    }
)


class AreaAdmin(JumboModelAdmin, TranslationAdmin):
    list_display = ('get_edit_icon', 'get_delete_icon', 'ordering', 'name', 'slug', 'status')
    fields = ('ordering', 'name', 'slug')
    prepopulated_fields = {'slug': ('name',)}


class TopicAdmin(JumboModelAdmin, TranslationAdmin):
    list_display = ('get_edit_icon', 'get_delete_icon', 'ordering', 'name', 'slug', 'status')
    fields = ('ordering', 'name', 'slug')
    prepopulated_fields = {'slug': ('name',)}


class FaqAdmin(JumboModelAdmin, TranslationAdmin):
    list_display = ('get_edit_icon', 'get_delete_icon', 'fuzzy', 'topic', 'question', 'creator', 'date_create')

    default_group_by = 'topic'
    prepopulated_fields = {'slug': ('question',)}

    fieldsets = (
        log_fieldset,
        (_('ordering'), {
            'fields': (
                ('ordering',),
            )
        }),
        (_('Faq'), {
            'fields': (
                ('topic', 'area'),
                ('question', 'slug',),
                ('answer',),
                ('fuzzy', 'fuzzy_reverse'),
            )
        }),
    )


admin.site.register(Faq, FaqAdmin)
admin.site.register(Area, AreaAdmin)
admin.site.register(Topic, TopicAdmin)
