from django.utils.translation import ugettext as _
from django import forms, http
from django.conf import settings
from django.core.urlresolvers import reverse
from django.contrib.auth.models import User
from django.template.loader import render_to_string
from django.utils.translation import get_language

from jmb.core.middleware.thread_local import get_current_user, get_request
from base.models import Profile
from allauth.account.forms import SignupForm
from allauth.socialaccount.forms import SignupForm as SocialSignupForm
from allauth.account.adapter import DefaultAccountAdapter
from allauth.account.utils import perform_login
from allauth.socialaccount.adapter import DefaultSocialAccountAdapter

from tre.marketing.client import mailing_client
from .models import Faq

class FaqForm(forms.ModelForm):

    class Meta:
        model = Faq
        exclude = []

    def clean(self):
        """The goal of this clean is to set fuzzy when a field is changed

        I'm claiming that people want to mark fuzzy it they changed the
        default language of this application
        """
        if not self.instance.id:
            return self.cleaned_data
        lang = get_language()
        key = 'content_{}'.format(lang)

        if not self.cleaned_data['fuzzy'] and (
                not self.cleaned_data[key] == getattr(self.instance, key)):
                self.cleaned_data['fuzzy'] = True
        return self.cleaned_data
