# coding: utf-8

from django.db import models
from django.utils.translation import ugettext_lazy as _

from ckeditor.fields import RichTextField

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


class Area(StatusModel, OrderedModel):
    """Grouping Area for topics"""

    name = models.CharField(
        max_length=150,
        verbose_name=_('name')
    )
    slug = models.SlugField(
        max_length=150,
        unique=True,
        verbose_name=_('slug'),
    )

    class Meta:
        ordering = ['ordering', 'name']
        managed = False
        verbose_name = _('Area')
        verbose_name_plural = _('Areas')

    def __unicode__(self):
        return self.name


class Topic(StatusModel, OrderedModel):
    """
    Generic Topics for FAQ question grouping
    """
    name = models.CharField(
        max_length=150,
        verbose_name=_('name')
    )
    slug = models.SlugField(
        max_length=150,
        unique=True,
        verbose_name=_('slug'),
    )

    class Meta:
        ordering = ['ordering', 'name']
        managed = False
        verbose_name = _('Topic')
        verbose_name_plural = _('Topics')

    def __unicode__(self):
        return self.name


class Faq(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Represents a frequently asked question.
    """
    topic = models.ForeignKey(
        Topic,
        related_name='faqs',
        verbose_name=_('topic')
    )
    question = models.CharField(
        max_length=255,
        verbose_name=_('question'),
        help_text=_('The actual question itself.'),
        unique=True,
    )
    slug = models.SlugField(
        max_length=255,
        unique=True,
        verbose_name=_('slug'),
        help_text=_('Unique identifier for better SEO resultso'),
    )
    answer = RichTextField(
        verbose_name=_('answer'),
        help_text='The answer text.'
    )
    protected = models.BooleanField(
        default=False,
        help_text=_('Set true if this question is only visible by authenticated users.')
    )
    area = models.ManyToManyField(Area)
    fuzzy = models.BooleanField(default=False)
    fuzzy_reverse = models.BooleanField(default=False)


    class Meta:
        ordering = ('ordering', 'date_create', 'question')
        managed = False
        verbose_name = _('Question')
        verbose_name_plural = _('Questions')

    def __unicode__(self):
        return u'{}'.format(self.question)
